install.packages("igraph")
require(igraph)
n = 30
kk = 2
Z <- c(sample(1:kk, size = kk, replace = FALSE),
       sample(1:kk, size = n-kk, replace = TRUE,prob = c(1,1)))
Z = Z[order(Z)]
theta <- matrix(0.1,kk,kk)
diag(theta) = 0.85
A = matrix(0,n,n)
for (i in 1:n){
  for (j in 1:n){
    A[i,j] = rbinom(1,1,prob=theta[Z[i],Z[j]])
  }
}
diag(A) = 0

par(mfrow=c(1,2))

net = graph.adjacency(A,mode="directed",weighted=TRUE,diag=FALSE) 
V(net)$color = ifelse(Z==1,"black","grey")
cluster = getDahl(fita,20)[[1]]
label = which(cluster!=Z)
V(net)$size = rep(5,30)
V(net)$size[label] = 10
V(net)$color[label] = "red"
plot(net, vertex.label=NA,edge.arrow.size=.3)



net = graph.adjacency(A,mode="directed",weighted=TRUE,diag=FALSE) 
plot.igraph(net,vertex.label=V(net)$name,layout=layout.fruchterman.reingold, vertex.label.color="blue",edge.color="red",edge.width=E(net)$weight/3, edge.arrow.size=.1,edge.curved=TRUE)

par(mfrow=c(1,3))
##comparison between different methods
MCMC = hist(compareequal2_0.2[[1]],nclass = 4, plot = FALSE)
plot(MCMC,xlim = c(0,4), main = "p=0.2,n=100,MCMC",xlab = "number of communities",lty = 1)
hist(compareequal2_0.2[[2]],xlim = c(0,4),breaks = 4, main = "p=0.2,n=100,NBM",xlab = "number of communities")
hist(compareequal2_0.2[[3]],xlim = c(0,4),breaks = 4, main = "p=0.2,n=100,BHM",xlab = "number of communities")

library('ggplot2')
qplot(x = as.factor(gjx[-c(1:1000)]), data = as.factor(gjx[-c(1:1000)]), geom = "histogram", binwidth = 1)

par(mfrow=c(1,1))
a = qplot(x = as.factor(compare_222[[1]]), geom = "histogram", binwidth = 0.4, xlim = c("1","2","3"), ylim = c(0,100), main = "p=0.22, n=100, MFM",xlab = "estimated # of communities")
b = qplot(x = as.factor(compare_222[[2]]), geom = "histogram", binwidth = 0.4, xlim = c("1","2","3"), ylim = c(0,100), main = "p=0.22, n=100, NBM",xlab = "estimated # of communities")
c = qplot(x = as.factor(compare_222[[3]]), geom = "histogram", binwidth = 0.4, xlim = c("1","2","3"), ylim = c(0,100), main = "p=0.22, n=100, BHM",xlab = "estimated # of communities")

a = a + theme(axis.text = element_text(colour = "blue",size=25),axis.title=element_text(size=28,face="bold"),title = element_text(size=20,face="bold")) + theme(plot.title = element_text(size=42))
b = b + theme(axis.text = element_text(colour = "blue",size=25),axis.title=element_text(size=28,face="bold"),title = element_text(size=20,face="bold")) + theme(plot.title = element_text(size=42))
c = c + theme(axis.text = element_text(colour = "blue",size=25),axis.title=element_text(size=28,face="bold"),title = element_text(size=20,face="bold")) + theme(plot.title = element_text(size=42))


vp.layout <- function(x, y) viewport(layout.pos.row=x, layout.pos.col=y)
arrange <- function(..., nrow=NULL, ncol=NULL, as.table=FALSE) {
  dots <- list(...)
  n <- length(dots)
  if(is.null(nrow) & is.null(ncol)) { nrow = floor(n/2) ; ncol = ceiling(n/nrow)}
  if(is.null(nrow)) { nrow = ceiling(n/ncol)}
  if(is.null(ncol)) { ncol = ceiling(n/nrow)}
  ## NOTE see n2mfrow in grDevices for possible alternative
  grid.newpage()
  pushViewport(viewport(layout=grid.layout(nrow,ncol) ) )
  ii.p <- 1
  for(ii.row in seq(1, nrow)){
    ii.table.row <- ii.row
    if(as.table) {ii.table.row <- nrow - ii.table.row + 1}
    for(ii.col in seq(1, ncol)){
      ii.table <- ii.p
      if(ii.p > n) break
      print(dots[[ii.table]], vp=vp.layout(ii.table.row, ii.col))
      ii.p <- ii.p + 1
    }
  }
}

arrange(a,b,c)

gjx = sapply(1:300000, function(x) {length(unique(fit11$Iterates[[x]][[1]]))})
ggplot(data=data.frame(gjx[-c(1:1000)]), aes(data.frame(gjx[-c(1:1000)])$gjx)) + 
geom_histogram(aes(y=..count../sum(..count..)),binwidth = 0.4)+ 
  labs(title="p=0.290, n=100, MFM") +
  labs(x="# of communities", y="proportion") +  xlim(c("1","2","3","4")) + theme(axis.text = element_text(colour = "blue",size=25),axis.title=element_text(size=28,face="bold"),title = element_text(size=20,face="bold")) + theme(plot.title = element_text(size=42))



  geom_histogram(aes(y =..density..), 
                 breaks=seq(20, 50, by = 2), 
                 col="red", 
                 fill="green", 
                 alpha = .2) + 
  geom_density(col=2) 


